[LinuxBIOS] r393 - LinuxBIOSv3/include/arch/x86

svn at openbios.org svn at openbios.org
Thu Jun 28 17:19:30 CEST 2007


Author: rminnich
Date: 2007-06-28 17:19:30 +0200 (Thu, 28 Jun 2007)
New Revision: 393

Modified:
   LinuxBIOSv3/include/arch/x86/amd_geodelx.h
Log:
Change case and improve comments.
Signed-off-by: Ronald G. Minnich <rminnich at gmail.com>
Acked-by: Uwe Hermann <uwe at hermann-uwe.de>
Acked-by: Peter Stuge <peter at stuge.se>


Modified: LinuxBIOSv3/include/arch/x86/amd_geodelx.h
===================================================================
--- LinuxBIOSv3/include/arch/x86/amd_geodelx.h	2007-06-28 14:06:39 UTC (rev 392)
+++ LinuxBIOSv3/include/arch/x86/amd_geodelx.h	2007-06-28 15:19:30 UTC (rev 393)
@@ -1214,23 +1214,26 @@
 
 /*
  * Write to a Virtual Register
+ * @param class_index The register index
+ * @param data The data to write
  */
-static inline void vrWrite(u16 wClassIndex, u16 wData)
+static inline void vr_write(u16 class_index, u16 data)
 {
-	outl(((u32) VR_UNLOCK << 16) | wClassIndex, VRC_INDEX);
-	outw(wData, VRC_DATA);
+	outl(((u32) VR_UNLOCK << 16) | class_index, VRC_INDEX);
+	outw(data, VRC_DATA);
 }
 
  /*
- * Read from a Virtual Register
- * Returns a 16-bit word of data
- */
-static inline u16 vrRead(u16 wClassIndex)
+  * Read from a Virtual Register
+  * @param class_index The register index
+  * @return the 16-bit word of data
+  */
+static inline u16 vr_ead(u16 class_index)
 {
-	u16 wData;
-	outl(((u32) VR_UNLOCK << 16) | wClassIndex, VRC_INDEX);
-	wData = inw(VRC_DATA);
-	return wData;
+	u16 data;
+	outl(((u32) VR_UNLOCK << 16) | class_index, VRC_INDEX);
+	data = inw(VRC_DATA);
+	return data;
 }
 
 /* support functions */





More information about the coreboot mailing list